@@ -48,12 +48,6 @@ struct xnee_ranges
 /* Standard includes */
 #include <stdio.h>
 
-/* X11 includes */
-#include <X11/Xmd.h>
-#include <X11/Xproto.h>
-#include <X11/Xos.h>
-#include <X11/Xlibint.h>  /* Warning, there be dragons here.... */
-#include <X11/Xlib.h>
 
 #include "libxnee/xnee.h"
 
