@@ -949,7 +949,7 @@ xnee_print_xnee_settings (xnee_data* xd, /*@null@*/ FILE* out)
   fprintf (out,  "##############################################\n");
   fprintf (out,  "# display %s\n",
 	   (xd->display==NULL) ? "NULL"  : xd->display);
-  fprintf (out,  "%s\n" , xnee_xns_key2string(XNEE_DISTRIBUTE_KEY));
+  fprintf (out,  "# %s\n" , xnee_xns_key2string(XNEE_DISTRIBUTE_KEY));
   ret = xnee_print_distr_list(xd, out);
   XNEE_RETURN_IF_ERR(ret);
 
@@ -959,10 +959,10 @@ xnee_print_xnee_settings (xnee_data* xd, /*@null@*/ FILE* out)
   fprintf (out,  "##############################################\n");
   fprintf (out,  "#      Files                                 #\n");
   fprintf (out,  "##############################################\n");
-  fprintf (out,   "%s %s\n",
+  fprintf (out,   "# %s %s\n",
 	   xnee_xns_key2string(XNEE_OUT_FILE_KEY),
 	   (xd->out_name==NULL) ? "stdout" : xd->out_name );
-  fprintf (out,   "%s %s\n",
+  fprintf (out,   "# %s %s\n",
 	   xnee_xns_key2string(XNEE_ERR_FILE_KEY),
 	   (xd->err_name==NULL) ? "stderr" : xd->err_name );
   
@@ -1108,10 +1108,14 @@ xnee_print_xnee_settings (xnee_data* xd, /*@null@*/ FILE* out)
   fprintf (out,  "#      Various                               #\n");
   fprintf (out,  "##############################################\n");
   /* Plugin */
-  fprintf (out,  "\n# Plugin file (0 means none)\n");
+  fprintf (out,  "\n# Plugin file \n");
+  if (xd->plugin_name==NULL)
+    {
+      fprintf (out,  "# ");
+    }      
   fprintf (out,  "%s       %s\n",
 	   xnee_xns_key2string(XNEE_PLUGIN_KEY),
-	   xd->plugin_name? xd->plugin_name : "0" ); 
+	   xd->plugin_name ); 
   
   /* Modes */
   fprintf (out,  "\n# Modes (currently not used)\n");
@@ -1127,13 +1131,18 @@ xnee_print_xnee_settings (xnee_data* xd, /*@null@*/ FILE* out)
 	   xnee_get_replay_offset_y(xd)); 
 
   fprintf (out,  "\n# Human printout of X11 data (instead of Xnee format)\n");
-  fprintf (out,  "%s  %d\n",
-	   xnee_xns_key2string(XNEE_HUMAN_PRINTOUT_KEY),
-	   (xnee_is_human_printout(xd)!=0)); 
+  if (!xnee_is_human_printout(xd))
+    {
+      fprintf (out,  "# ");
+    }      
+  fprintf (out,  "%s  \n",
+	   xnee_xns_key2string(XNEE_HUMAN_PRINTOUT_KEY)); 
 
   
   fprintf (out,  "\n# Delay before starting record/replay\n");
-  fprintf (out,  "# %d\n", xnee_get_interval(xd) ); 
+  fprintf (out,  "# %s %d\n", 
+	   xnee_xns_key2string(XNEE_DELAY_TIME_KEY),
+	   xnee_get_interval(xd) ); 
 
   
 
@@ -1244,8 +1253,9 @@ xnee_store_mouse_pos (xnee_data* xd )
 	       "%s " 
 	       "%s=%d " 
 	       "%s=%d \n" ,
-	       XNEE_FAKE_MOTION,XNEE_FAKE_X_ARG,XNEE_FAKE_Y_ARG,
-	       rx, ry );
+	       XNEE_FAKE_MOTION,
+	       XNEE_FAKE_X_ARG, rx, 
+	       XNEE_FAKE_Y_ARG, ry );
 }
 
 
@@ -1262,15 +1272,14 @@ xnee_version(xnee_data* xd)
   xnee_verbose ((xd, " --> xnee_version\n"));
   fprintf (stderr, "%s ",PACKAGE);
   fprintf (stderr, "%s\n",VERSION);
-  fprintf (stderr, "Copyright (C) 2000,2001,2002,2003,2004, 2005 Henrik Sandklef \n");
+  fprintf (stderr, "Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Henrik Sandklef \n");
   fprintf (stderr, "%s and all its included programs come with ", PACKAGE);
   fprintf (stderr, "NO WARRANTY,\nto the extent permitted by law.\n" );
   fprintf (stderr, "This is free software, and you may redistribute\n");
   fprintf (stderr, "copies of it under terms of GNU General Public License.\n");
-  fprintf (stderr, "For questions: %s  \n", XNEE_MAIL);
-  fprintf (stderr, "Xnee: Xnee's not an Event Emulator %s \n", XNEE_HOME_URL);
-  fprintf (stderr, "GPL:  Gnu General Public License   %s\n",  GNU_HOME_URL);
-  fprintf (stderr, "FSF:  Free Software Foundation     %s\n",  FSF_HOME_URL);
+  fprintf (stderr, "For questions: \n\t%s  \n", XNEE_MAIL);
+  fprintf (stderr, "Xnee, Xnee's not an Event Emulator \n\t%s \n", XNEE_HOME_URL);
+  fprintf (stderr, "GPL, GNU General Public License \n\t%s\n",  GNU_HOME_URL);
   xnee_verbose ((xd, " <-- xnee_version\n"));
 }
 
