@@ -114,8 +114,6 @@ xnee_expression_handle_session(xnee_data *xd,
 				xindata);
   if (do_continue==XNEE_PRIMITIVE_DATA) { return (XNEE_PRIMITIVE_DATA); }
 
-
-
   /* Is it a meta string */
   do_continue = xnee_expression_handle_comment(xd, tmp);
   if (do_continue==XNEE_META_DATA) { return (do_continue); }
@@ -166,7 +164,11 @@ xnee_expression_handle_project(xnee_data *xd, char *tmp)
   /* Is it a replayable data */
   do_continue = xnee_is_replayable(xd, tmp);
   if (do_continue) { return (XNEE_REPLAY_DATA); }
-  
+
+  /* Is it a script data */
+  do_continue = xnee_is_script(xd, tmp);
+  if (do_continue) { return (XNEE_PRIMITIVE_DATA); }
+
   /* Is it a meta string */
   do_continue = xnee_expression_handle_comment(xd, tmp);
   if (do_continue==XNEE_META_DATA) { return (do_continue); }
@@ -207,14 +209,14 @@ xnee_expression_handle_replay(xnee_data *xd,
     {    
       xindata->oldtime = xindata->newtime ;
       ret = sscanf(tmp, "%d,%d,%d,%d,%d,%d,%d,%lu",
-		      &xindata->type, 
-		      &xindata->u.event.type, 
-		      &xindata->u.event.x,
-		      &xindata->u.event.y, 
-		      &xindata->u.event.button,
-		      &xindata->u.event.keycode, 
-		      &xindata->u.event.screen_nr,
-		      &xindata->newtime);
+		   &xindata->type, 
+		   &xindata->u.event.type, 
+		   &xindata->u.event.x,
+		   &xindata->u.event.y, 
+		   &xindata->u.event.button,
+		   &xindata->u.event.keycode, 
+		   &xindata->u.event.screen_nr,
+		   &xindata->newtime);
       if (ret < 8)    /* NUM ARGS */
 	{
 	  (void)xnee_print_error("Error in file %s \n", xd->data_name);
@@ -308,10 +310,7 @@ xnee_expression_handle_settings(xnee_data *xd, char *tmp, int synt_mode)
   ret_strptr = xnee_str2strptr(my_tmp, synt_mode);
 
 
-  if (xnee_is_verbose(xd))
-    {
-      xnee_print_strptr(ret_strptr);
-    }
+  xnee_print_strptr(xd, ret_strptr);
 
   ret = xnee_parse_xns_option(xd, ret_strptr, &args_used) ;
 
@@ -601,6 +600,8 @@ xnee_expression_handle_prim_sub(xnee_data *xd, char *arg, xnee_script_s *xss)
 	  return XNEE_SYNTAX_ERROR;
 	}
 
+
+
       str++;
       /* skip leading blanks */
       while ( str[0] == ' ' ) str++ ;
@@ -649,7 +650,6 @@ xnee_expression_handle_prim_sub(xnee_data *xd, char *arg, xnee_script_s *xss)
       /* key=a key=shift etc */
       else if (strncmp(var,XNEE_FAKE_KEY_ARG,strlen(XNEE_FAKE_KEY_ARG))==0)
 	{
-	  
 	  if (strlen(val)==1)  
 	    {
 	      valp = &val[0];
@@ -659,7 +659,7 @@ xnee_expression_handle_prim_sub(xnee_data *xd, char *arg, xnee_script_s *xss)
 		{
 		  val[0]=' ';
 		}
-	      
+
 	      xss->key = xnee_char2keycode (xd,val[0],&xss->kc);
 	      if ( xss->kc.kc != 0 )
 		{
@@ -724,6 +724,8 @@ xnee_expression_handle_prim(xnee_data *xd, char *str, xnee_intercept_data * xind
 
   xnee_verbose ((xd, "handling primitive: %s\n", str));
 
+  memset(&xss, 0, sizeof(xnee_script_s));
+
   if (str == NULL)
     {
       return 0;
@@ -821,3 +823,14 @@ xnee_is_replayable(xnee_data *xd, char *tmp)
     }
   return 0;
 }
+
+
+int
+xnee_is_script(xnee_data *xd, char *tmp)
+{
+  if ( strncmp(tmp, "xnee-", strlen("xnee-")))
+    {
+      return 1;
+    }
+  return 0;
+}
